==> puppet_2.7.18.orig.tar.gz: puppet-2.7.18/spec/shared_behaviours/file_serving_model.rb <==
#!/usr/bin/env rspec

shared_examples_for "a file_serving model" do
  include PuppetSpec::Files

  describe "#indirection" do
    before :each do
      # Never connect to the network, no matter what
      described_class.indirection.terminus(:rest).class.any_instance.stubs(:find)
    end

    describe "when running the master application" do
      before :each do
        Puppet::Application[:master].setup_terminuses
      end

      {
       "/etc/sudoers"                    => :file_server,
       "file:///etc/sudoers"             => :file_server,
       "puppet:///modules/foo/bar"       => :file_server,
       "puppet://server/modules/foo/bar" => :file_server,
      }.each do |key, terminus|
        it "should use the #{terminus} terminus when requesting #{key.inspect}" do
          described_class.indirection.terminus(terminus).class.any_instance.expects(:find)

          described_class.indirection.find(key)
        end
      end
    end

    describe "when running the apply application" do
      before :each do
        # Stub this so we can set the 'name' setting
        Puppet::Util::Settings::ReadOnly.stubs(:include?)
        Puppet[:name] = 'apply'
      end

      {
       "/etc/sudoers"                    => :file,
       "file:///etc/sudoers"             => :file,
       "puppet:///modules/foo/bar"       => :file_server,
       "puppet://server/modules/foo/bar" => :rest,
      }.each do |key, terminus|
        it "should use the #{terminus} terminus when requesting #{key.inspect}" do
          described_class.indirection.terminus(terminus).class.any_instance.expects(:find)

          described_class.indirection.find(key)
        end
      end
    end

    describe "when running another application" do
      before :each do
        # Stub this so we can set the 'name' setting
        Puppet::Util::Settings::ReadOnly.stubs(:include?)
        Puppet[:name] = 'agent'
      end

      {
       "/etc/sudoers"                    => :file,
       "file:///etc/sudoers"             => :file,
       "puppet:///modules/foo/bar"       => :rest,
       "puppet://server/modules/foo/bar" => :rest,
      }.each do |key, terminus|
        it "should use the #{terminus} terminus when requesting #{key.inspect}" do
          described_class.indirection.terminus(terminus).class.any_instance.expects(:find)

          described_class.indirection.find(key)
        end
      end
    end
  end
end

==> puppet_2.7.19.orig.tar.gz: puppet-2.7.19rc3/spec/shared_behaviours/file_serving_model.rb <==
#!/usr/bin/env rspec

shared_examples_for "a file_serving model" do
  include PuppetSpec::Files

  describe "#indirection" do
    localpath = PuppetSpec::Files.make_absolute("/etc/sudoers")
    localurl = "file://" + localpath

    before :each do
      # Never connect to the network, no matter what
      described_class.indirection.terminus(:rest).class.any_instance.stubs(:find)
    end

    describe "when running the master application" do
      before :each do
        Puppet::Application[:master].setup_terminuses
      end

      {
       localpath     => :file_server,
       localurl => :file_server,
       "puppet:///modules/foo/bar"       => :file_server,
       "puppet://server/modules/foo/bar" => :file_server,
      }.each do |key, terminus|
        it "should use the #{terminus} terminus when requesting #{key.inspect}" do
          described_class.indirection.terminus(terminus).class.any_instance.expects(:find)

          described_class.indirection.find(key)
        end
      end
    end

    describe "when running the apply application" do
      before :each do
        # Stub this so we can set the 'name' setting
        Puppet::Util::Settings::ReadOnly.stubs(:include?)
        Puppet[:name] = 'apply'
      end

      {
       localpath => :file,
       localurl => :file,
       "puppet:///modules/foo/bar"       => :file_server,
       "puppet://server/modules/foo/bar" => :rest,
      }.each do |key, terminus|
        it "should use the #{terminus} terminus when requesting #{key.inspect}" do
          described_class.indirection.terminus(terminus).class.any_instance.expects(:find)

          described_class.indirection.find(key)
        end
      end
    end

    describe "when running another application" do
      before :each do
        # Stub this so we can set the 'name' setting
        Puppet::Util::Settings::ReadOnly.stubs(:include?)
        Puppet[:name] = 'agent'
      end

      {
       localpath => :file,
       localurl => :file,
       "puppet:///modules/foo/bar"       => :rest,
       "puppet://server/modules/foo/bar" => :rest,
      }.each do |key, terminus|
        it "should use the #{terminus} terminus when requesting #{key.inspect}" do
          described_class.indirection.terminus(terminus).class.any_instance.expects(:find)

          described_class.indirection.find(key)
        end
      end
    end
  end
end
